@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.6
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: gdal_edit.py c1fbba933ab495ea744145c45921b91a2053c513 2018-04-17 18:56:03 +1000 Ben Elliston $
+# $Id: gdal_edit.py 5f6ced88218cd95f728604eaf145ff3516708ec2 2018-08-24 17:32:52 +0200 Even Rouault $
 #
 #  Project:  GDAL samples
 #  Purpose:  Edit in place various information of an existing GDAL dataset
@@ -37,10 +37,11 @@ from osgeo import osr
 
 def Usage():
     print('Usage: gdal_edit [--help-general] [-ro] [-a_srs srs_def] [-a_ullr ulx uly lrx lry]')
-    print('                 [-tr xres yres] [-unsetgt] [-a_nodata value] [-unsetnodata]')
+    print('                 [-tr xres yres] [-unsetgt] [-unsetrpc] [-a_nodata value] [-unsetnodata]')
     print('                 [-offset value] [-scale value]')
     print('                 [-colorinterp_X red|green|blue|alpha|gray|undefined]*')
     print('                 [-unsetstats] [-stats] [-approx_stats]')
+    print('                 [-setstats min max mean stddev]')
     print('                 [-gcp pixel line easting northing [elevation]]*')
     print('                 [-unsetmd] [-oo NAME=VALUE]* [-mo "META-TAG=VALUE"]*  datasetname')
     print('')
@@ -78,6 +79,7 @@ def gdal_edit(argv):
     unsetgt = False
     unsetstats = False
     stats = False
+    setstats = False
     approx_stats = False
     unsetmd = False
     ro = False
@@ -87,6 +89,7 @@ def gdal_edit(argv):
     offset = None
     scale = None
     colorinterp = {}
+    unsetrpc = False
 
     i = 1
     argc = len(argv)
@@ -140,6 +143,8 @@ def gdal_edit(argv):
             gcp_list.append(gcp)
         elif argv[i] == '-unsetgt':
             unsetgt = True
+        elif argv[i] == '-unsetrpc':
+            unsetrpc = True
         elif argv[i] == '-unsetstats':
             unsetstats = True
         elif argv[i] == '-approx_stats':
@@ -147,6 +152,29 @@ def gdal_edit(argv):
             approx_stats = True
         elif argv[i] == '-stats':
             stats = True
+        elif argv[i] == '-setstats' and i < len(argv)-4:
+            stats = True
+            setstats = True
+            if argv[i + 1] != 'None':
+                statsmin = float(argv[i + 1])
+            else:
+                statsmin = None
+            i = i + 1
+            if argv[i + 1] != 'None':
+                statsmax = float(argv[i + 1])
+            else:
+                statsmax = None
+            i = i + 1
+            if argv[i + 1] != 'None':
+                statsmean = float(argv[i + 1])
+            else:
+                statsmean = None
+            i = i + 1
+            if argv[i + 1] != 'None':
+                statsdev = float(argv[i + 1])
+            else:
+                statsdev = None
+            i = i + 1
         elif argv[i] == '-unsetmd':
             unsetmd = True
         elif argv[i] == '-unsetnodata':
@@ -190,10 +218,10 @@ def gdal_edit(argv):
         return Usage()
 
     if (srs is None and lry is None and yres is None and not unsetgt and
-            not unsetstats and not stats and nodata is None and
-            len(molist) == 0 and not unsetmd and len(gcp_list) == 0 and
-            not unsetnodata and len(colorinterp) == 0 and
-            scale is None and offset is None):
+            not unsetstats and not stats and not setstats and nodata is None and
+            not molist and not unsetmd and not gcp_list and
+            not unsetnodata and not colorinterp and
+            scale is None and offset is None and not unsetrpc):
         print('No option specified')
         print('')
         return Usage()
@@ -242,7 +270,7 @@ def gdal_edit(argv):
             print('Failed to process SRS definition: %s' % srs)
             return -1
         wkt = sr.ExportToWkt()
-        if len(gcp_list) == 0:
+        if not gcp_list:
             ds.SetProjection(wkt)
 
     if lry is not None:
@@ -266,7 +294,7 @@ def gdal_edit(argv):
         else:
             ds.SetGeoTransform([0, 1, 0, 0, 0, 1])
 
-    if len(gcp_list) > 0:
+    if gcp_list:
         if wkt is None:
             wkt = ds.GetGCPProjection()
         if wkt is None:
@@ -299,7 +327,22 @@ def gdal_edit(argv):
         for i in range(ds.RasterCount):
             ds.GetRasterBand(i + 1).ComputeStatistics(approx_stats)
 
-    if len(molist) != 0:
+    if setstats:
+        for i in range(ds.RasterCount):
+            if statsmin is None or statsmax is None or statsmean is None or statsdev is None:
+                ds.GetRasterBand(i+1).ComputeStatistics(approx_stats)
+                min,max,mean,stdev = ds.GetRasterBand(i+1).GetStatistics(approx_stats,True)
+                if statsmin is None:
+                    statsmin = min
+                if statsmax is None:
+                    statsmax = max
+                if statsmean is None:
+                    statsmean = mean
+                if statsdev is None:
+                    statsdev = stdev
+            ds.GetRasterBand(i+1).SetStatistics(statsmin, statsmax, statsmean, statsdev)
+
+    if molist:
         if unsetmd:
             md = {}
         else:
@@ -315,6 +358,9 @@ def gdal_edit(argv):
     for band in colorinterp:
         ds.GetRasterBand(band).SetColorInterpretation(colorinterp[band])
 
+    if unsetrpc:
+        ds.SetMetadata(None, 'RPC')
+
     ds = band = None
 
     return 0
