@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.6
 # ******************************************************************************
-#  $Id: rgb2pct.py 1121758f74589f8850193a5baced7ab1335a4b39 2018-04-20 11:27:52 +0200 Even Rouault $
+#  $Id: rgb2pct.py 8e263710cb425c4a8b76b1f363b98be41ea0a983 2018-04-30 19:40:20 +1000 Ben Elliston $
 #
 #  Name:     rgb2pct
 #  Project:  GDAL Python Interface
@@ -60,7 +60,7 @@ def GetOutputDriversFor(filename):
         if (drv.GetMetadataItem(gdal.DCAP_CREATE) is not None or
             drv.GetMetadataItem(gdal.DCAP_CREATECOPY) is not None) and \
            drv.GetMetadataItem(gdal.DCAP_RASTER) is not None:
-            if len(ext) > 0 and DoesDriverHandleExtension(drv, ext):
+            if ext and DoesDriverHandleExtension(drv, ext):
                 drv_list.append(drv.ShortName)
             else:
                 prefix = drv.GetMetadataItem(gdal.DMD_CONNECTION_PREFIX)
@@ -69,7 +69,7 @@ def GetOutputDriversFor(filename):
 
     # GMT is registered before netCDF for opening reasons, but we want
     # netCDF to be used by default for output.
-    if ext.lower() == 'nc' and len(drv_list) == 0 and \
+    if ext.lower() == 'nc' and not drv_list and \
        drv_list[0].upper() == 'GMT' and drv_list[1].upper() == 'NETCDF':
         drv_list = ['NETCDF', 'GMT']
 
@@ -78,9 +78,9 @@ def GetOutputDriversFor(filename):
 
 def GetOutputDriverFor(filename):
     drv_list = GetOutputDriversFor(filename)
-    if len(drv_list) == 0:
+    if not drv_list:
         ext = GetExtension(filename)
-        if len(ext) == 0:
+        if not ext:
             return 'GTiff'
         else:
             raise Exception("Cannot guess driver for %s" % filename)
@@ -94,7 +94,7 @@ def GetOutputDriverFor(filename):
 
 
 color_count = 256
-format = None
+frmt = None
 src_filename = None
 dst_filename = None
 pct_filename = None
@@ -111,7 +111,7 @@ while i < len(argv):
 
     if arg == '-of' or arg == '-f':
         i = i + 1
-        format = argv[i]
+        frmt = argv[i]
 
     elif arg == '-n':
         i = i + 1
@@ -149,12 +149,12 @@ if src_ds.RasterCount < 3:
 
 # Ensure we recognise the driver.
 
-if format is None:
-    format = GetOutputDriverFor(dst_filename)
+if frmt is None:
+    frmt = GetOutputDriverFor(dst_filename)
 
-dst_driver = gdal.GetDriverByName(format)
+dst_driver = gdal.GetDriverByName(frmt)
 if dst_driver is None:
-    print('"%s" driver not registered.' % format)
+    print('"%s" driver not registered.' % frmt)
     sys.exit(1)
 
 # Generate palette
